Index: src/objects.h |
diff --git a/src/objects.h b/src/objects.h |
index 37016da8916aa86db6ae03b743334d1c47bfc4e4..77bc06430c7f4730b27412dd56742a9f6354b31a 100644 |
--- a/src/objects.h |
+++ b/src/objects.h |
@@ -1997,11 +1997,14 @@ class JSReceiver: public HeapObject { |
MUST_USE_RESULT static Maybe<bool> HasInPrototypeChain( |
Isolate* isolate, Handle<JSReceiver> object, Handle<Object> proto); |
// Reads all enumerable own properties of source and adds them to target, |
// using either Set or CreateDataProperty depending on the use_set argument. |
MUST_USE_RESULT static Maybe<bool> SetOrCopyDataProperties( |
Isolate* isolate, Handle<JSReceiver> target, Handle<Object> source, |
- bool use_set); |
+ const ScopedVector<Handle<Name>>* excluded_properties = nullptr, |
+ bool use_set = true); |
// Implementation of [[HasProperty]], ECMA-262 5th edition, section 8.12.6. |
MUST_USE_RESULT static Maybe<bool> HasProperty(LookupIterator* it); |
@@ -1997,11 +1997,14 @@ class JSReceiver: public HeapObject { |
MUST_USE_RESULT static Maybe<bool> HasInPrototypeChain( |
Isolate* isolate, Handle<JSReceiver> object, Handle<Object> proto); |
- // Reads all enumerable own properties of source and adds them to target, |
- // using either Set or CreateDataProperty depending on the use_set argument. |
+ // Reads all enumerable own properties of source and adds them to |
+ // target, using either Set or CreateDataProperty depending on the |
+ // use_set argument. This only copies values not present in the |
+ // maybe_excluded_properties list. |
MUST_USE_RESULT static Maybe<bool> SetOrCopyDataProperties( |
Isolate* isolate, Handle<JSReceiver> target, Handle<Object> source, |